#property indicator_chart_window
#property indicator_buffers 2
#property indicator_color1  clrLimeGreen 
#property indicator_color2  clrRed 
#property strict

//
//
//
//
//

extern ENUM_TIMEFRAMES    TimeFrame       = PERIOD_CURRENT; // Timeframe to use
extern int                FastEma         = 12;             // Osma fast period
extern int                SlowEma         = 26;             // Osma slow period
extern int                SignalPeriod    = 9;              // Osma signal period
extern ENUM_APPLIED_PRICE Price           = PRICE_CLOSE;    // Price to use
extern bool               alertsOn        = true;           // Turn alerts on?
extern bool               alertsOnCurrent = true;           // Alerts on current (still opened) bar?
extern bool               alertsMessage   = true;           // Alerts should display alert message?
extern bool               alertsSound     = true;           // Alerts should play alert sound?
extern bool               alertsPushNotif = false;          // Alerts should send alert notification?
extern bool               alertsEmail     = false;          // Alerts should send alert email?
extern int                ArrowCodeUp     = 233;            // Up Arrow code
extern int                ArrowCodeDn     = 234;            // Down Arrow code
extern double             ArrowGapUp      = 0.5;            // Gap for arrow up        
extern double             ArrowGapDn      = 0.5;            // Gap for arrow down
extern int                ArrowSizeUp     = 1;              // Up Arrow Size 
extern int                ArrowSizeDn     = 1;              // Down Arrow Size
extern bool               ArrowOnFirst    = true;           // Arrow on first bars

//
//
//
//
//

double arrUp[];
double arrDn[];
double trend[];
string indicatorFileName;
bool   returnBars;

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
//
//
//
//
//

int init()
{

   IndicatorBuffers(3);  
   SetIndexBuffer(0,arrUp); SetIndexStyle(0,DRAW_ARROW,0,ArrowSizeUp); SetIndexArrow(0,ArrowCodeUp);
   SetIndexBuffer(1,arrDn); SetIndexStyle(1,DRAW_ARROW,0,ArrowSizeDn); SetIndexArrow(1,ArrowCodeDn);
   SetIndexBuffer(2,trend);
   
   indicatorFileName = WindowExpertName();
   returnBars        = TimeFrame==-99;
   TimeFrame         = MathMax(TimeFrame,_Period);      
         
   IndicatorShortName(timeFrameToString(TimeFrame)+  " Osma Cross ");
return(0);
}

int deinit()  {   return(0);  }

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
//
//

int start()
{
   int i,counted_bars=IndicatorCounted();
      if(counted_bars<0) return(-1);
      if(counted_bars>0) counted_bars--;
         int limit = MathMin(Bars-counted_bars,Bars-1);
         if (returnBars) { arrUp[0] = MathMin(limit+1,Bars-1); return(0); }

   //
   //
   //
   //
   //

   if (TimeFrame == Period())
   {
     for(i=limit; i>=0; i--)
     {
         double osma = iOsMA(NULL,0,FastEma,SlowEma,SignalPeriod,Price,i);
         arrUp[i] = EMPTY_VALUE; 
         arrDn[i] = EMPTY_VALUE;
         if (i<Bars-1)
         { 
           trend[i] = trend[i+1];
           if (osma>0) trend[i] = 1;
           if (osma<0) trend[i] =-1;
         }
         if (i<Bars-1 && trend[i]!= trend[i+1])
         {
            if (trend[i] ==  1) arrUp[i] = Low[i] -iATR(NULL,0,15,i)*ArrowGapUp;
            if (trend[i] == -1) arrDn[i] = High[i]+iATR(NULL,0,15,i)*ArrowGapDn;
          }
      
    }
   
   //
   //
   //
   //
   //
   
   if (alertsOn)
   {
      int whichBar = 1; if (alertsOnCurrent) whichBar = 0;
      if (trend[whichBar] != trend[whichBar+1])
      if (trend[whichBar] == 1)
            doAlert("crossing zero up");
      else  doAlert("crossing zero down");       
   }   
	return(0);	
   }
   
   //
   //
   //
   //
   //

   limit = (int)MathMax(limit,MathMin(Bars-1,iCustom(NULL,TimeFrame,indicatorFileName,-99,0,0)*TimeFrame/Period()));
   for (i=limit; i>=0; i--)
   {
      int y = iBarShift(NULL,TimeFrame,Time[i]);
      int x = y;
      if (ArrowOnFirst)
            {  if (i<Bars-1) x = iBarShift(NULL,TimeFrame,Time[i+1]);          }
      else  {  if (i>0) x = iBarShift(NULL,TimeFrame,Time[i-1]); else x = -1;  }
         arrUp[i] = EMPTY_VALUE;
         arrDn[i] = EMPTY_VALUE;
         if (x!=y)
         {
            arrUp[i] = iCustom(NULL,TimeFrame,indicatorFileName,PERIOD_CURRENT,FastEma,SlowEma,SignalPeriod,Price,alertsOn,alertsOnCurrent,alertsMessage,alertsSound,alertsPushNotif,alertsEmail,0,y);
            arrDn[i] = iCustom(NULL,TimeFrame,indicatorFileName,PERIOD_CURRENT,FastEma,SlowEma,SignalPeriod,Price,alertsOn,alertsOnCurrent,alertsMessage,alertsSound,alertsPushNotif,alertsEmail,1,y);
         }
    }
return(0);
}

//-------------------------------------------------------------------
//
//-------------------------------------------------------------------
//
//
//
//
//

string sTfTable[] = {"M1","M5","M15","M30","H1","H4","D1","W1","MN"};
int    iTfTable[] = {1,5,15,30,60,240,1440,10080,43200};

string timeFrameToString(int tf)
{
   for (int i=ArraySize(iTfTable)-1; i>=0; i--) 
         if (tf==iTfTable[i]) return(sTfTable[i]);
                              return("");
}

//------------------------------------------------------------------
//                                                                  
//------------------------------------------------------------------
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message = StringConcatenate(Symbol()," ",timeFrameToString(_Period)," at ",TimeToStr(TimeLocal(),TIME_SECONDS)+" Osma ",doWhat);
             if (alertsMessage)   Alert(message);
             if (alertsPushNotif) SendNotification(message);
             if (alertsEmail)     SendMail(StringConcatenate(Symbol()," Osma "),message);
             if (alertsSound)     PlaySound("alert2.wav");
      }
}

